%define major 5.2
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s
%define alt_priority %(echo %{major} | sed -e 's/[^0-9]//g')

Summary:	Powerful, light-weight programming language
Name:		lua
Version:	5.2.4
%define subrel 1
Release:	%mkrel 3
License:	MIT
Group:		Development/Other
URL:		http://www.lua.org/
Source0:	http://www.lua.org/ftp/%{name}-%{version}.tar.gz
Source1:	lua.pc
Patch0:		lua-5.2.1-dynlib.patch
Patch2:		lua-5.2.0-modules_path.patch
Patch3:		lua-5.2.4-CVE-2020-24370.patch
Provides:	lua%{major}
Requires(post):	update-alternatives
Requires(postun):	update-alternatives
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(ncurses)

%description
Lua is a programming language originally designed for extending applications,
but also frequently used as a general-purpose, stand-alone language. Lua
combines simple procedural syntax (similar to Pascal) with powerful data
description constructs based on associative arrays and extensible semantics.
Lua is dynamically typed, interpreted from bytecodes, and has automatic memory
management, making it ideal for configuration, scripting, and rapid
prototyping. Lua is implemented as a small library of C functions, written in
ANSI C, and compiles unmodified in all known platforms. The implementation
goals are simplicity, efficiency, portability, and low embedding cost.

%package -n %{libname}
Summary:	Powerful, light-weight programming language
Group:		Development/Other

%description -n %{libname}
Lua is a programming language originally designed for extending applications,
but also frequently used as a general-purpose, stand-alone language. Lua
combines simple procedural syntax (similar to Pascal) with powerful data
description constructs based on associative arrays and extensible semantics.
Lua is dynamically typed, interpreted from bytecodes, and has automatic memory
management, making it ideal for configuration, scripting, and rapid
prototyping. Lua is implemented as a small library of C functions, written in
ANSI C, and compiles unmodified in all known platforms. The implementation
goals are simplicity, efficiency, portability, and low embedding cost.

%package -n %{develname}
Summary:	Headers and development files for Lua
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Provides:	liblua%{major}-devel = %{version}-%{release}
Provides:	lua-devel = %{version}-%{release}
Provides:	lua%{major}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the headers and development files for Lua.

%package -n	%{staticname}
Summary:	Static development files for Lua
Group:		Development/Other
Provides:	lua-devel-static = %{version}-%{release}
Provides:	lua-static-devel = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}

%description -n	%{staticname}
This package contains the static development files for Lua.

%prep
%setup -q
%patch0 -p1 -b .dynlib
%patch2 -p1 -b .modules
%patch3 -p1 -b .CVE-2020-24370
mkdir -p etc
cp %{SOURCE1} ./etc/
sed -i -e 's/@MAJOR_VERSION@/%{major}/g' ./etc/lua.pc
sed -i -e 's/@FULL_VERSION@/%{version}/g' ./etc/lua.pc

sed -i -e "s|/usr/local|%{_prefix}|g" Makefile
sed -i -e "s|/lib|/%{_lib}|g" Makefile
sed -i -e "s|/usr/local|%{_prefix}|g" src/luaconf.h
sed -i -e "s|/lib|/%{_lib}|g" src/luaconf.h
sed -i -e "s|/man/man1|/share/man/man1|g" Makefile
sed -i -e "s|\$(V)|%{major}|g" src/Makefile

%build
sed -i 's/-lncurses/-lncursesw/g' */Makefile*
# (tv) enable compat module (fix building rpm with lua-5.2):
%make_build linux CFLAGS="%{optflags} -fPIC -DLUA_USE_LINUX -DLUA_COMPAT_MODULE"

%install
%make_install INSTALL_TOP=%{buildroot}%{_prefix} INSTALL_LIB=%{buildroot}%{_libdir} INSTALL_MAN=%{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_libdir}/lua/%{major}/
install -d %{buildroot}%{_datadir}/lua/%{major}/

install -m 755 src/liblua.so.%{major}* %{buildroot}%{_libdir}
ln -s liblua.so.%{major} %{buildroot}%{_libdir}/liblua.so

install -d -m 755 %{buildroot}%{_libdir}/pkgconfig/
install -m 644 etc/lua.pc %{buildroot}%{_libdir}/pkgconfig/

# for update-alternatives
mv %{buildroot}%{_bindir}/lua %{buildroot}%{_bindir}/lua%{major}
mv %{buildroot}%{_bindir}/luac %{buildroot}%{_bindir}/luac%{major}

%post
/usr/sbin/update-alternatives --install %{_bindir}/lua lua %{_bindir}/lua%{major} %{alt_priority} --slave %{_bindir}/luac luac %{_bindir}/luac%{major}

%postun
[[ -f %{_bindir}/lua%{major} ]] || /usr/sbin/update-alternatives --remove lua %{_bindir}/lua%{major}

%files
%doc doc/*{.html,.css,.gif,.png}
%doc README
%{_bindir}/*
%{_mandir}/man1/*
%dir %{_datadir}/lua/%{major}

%files -n %{libname}
%{_libdir}/liblua.so.%{major}
%dir %{_libdir}/lua/%{major}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/liblua.so

%files -n %{staticname}
%{_libdir}/*.a


%changelog
* Wed Sep 02 2020 ns80 <ns80> 5.2.4-3.1.mga7
+ Revision: 1620893
- add patch for CVE-2020-24370 (mga#27213)

* Fri Oct 05 2018 umeabot <umeabot> 5.2.4-3.mga7
+ Revision: 1317846
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Tue Jan 02 2018 wally <wally> 5.2.4-2.mga7
+ Revision: 1189323
- rebuild for new readline

* Wed Sep 07 2016 luigiwalser <luigiwalser> 5.2.4-1.mga6
+ Revision: 1050407
- 5.2.4

* Tue Apr 05 2016 pterjan <pterjan> 5.2.3-9.mga6
+ Revision: 998787
- Fix file list

* Fri Mar 04 2016 luigiwalser <luigiwalser> 5.2.3-8.mga6
+ Revision: 985779
- rebuild lua 5.2
- restore lua 5.2 as lua

* Fri Aug 21 2015 tmb <tmb> 5.2.3-7.mga6
+ Revision: 867620
- rebuild for new gcc

* Mon Oct 20 2014 tmb <tmb> 5.2.3-6.mga5
+ Revision: 792175
- require update-alternatives for post(un) scripts

* Wed Oct 15 2014 umeabot <umeabot> 5.2.3-5.mga5
+ Revision: 739870
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.2.3-4.mga5
+ Revision: 682024
- Mageia 5 Mass Rebuild

* Mon Jun 30 2014 tv <tv> 5.2.3-3.mga5
+ Revision: 641667
- enable compat module (thus fixing building rpm with lua-5.2)
- simplify patch
+ colin <colin>
- Own the /usr/{share,lib[64]}/lua/5.2 dirs.

* Sun Mar 02 2014 luigiwalser <luigiwalser> 5.2.3-1.mga5
+ Revision: 598630
- 5.2.3

* Sat Oct 19 2013 umeabot <umeabot> 5.2.2-2.mga4
+ Revision: 522814
- Mageia 4 Mass Rebuild

* Thu Mar 28 2013 guillomovitch <guillomovitch> 5.2.2-1.mga3
+ Revision: 405991
- new version

* Sat Jan 12 2013 umeabot <umeabot> 5.2.1-2.mga3
+ Revision: 359041
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 luigiwalser <luigiwalser> 5.2.1-1.mga3
+ Revision: 289798
- 5.2.1
+ fwang <fwang>
- drop old taball

* Sat Jun 02 2012 blue_prawn <blue_prawn> 5.2.0-1.mga3
+ Revision: 253448
- sync tarball lua-5.2.0.tar.gz
- update to last version lua-5.2.0

* Sat Jun 02 2012 blue_prawn <blue_prawn> 5.1.4-11.mga3
+ Revision: 253361
- the .o file of the interactive interpreter should not be included in the .so lib

* Fri Mar 09 2012 tv <tv> 5.1.4-10.mga2
+ Revision: 221977
- link with libncursesw instead of libncurses else rpm is linked with
  both libncursesw & libncurses and text installer crashes (mga#4724)

* Sun Jan 09 2011 shikamaru <shikamaru> 5.1.4-9.mga1
+ Revision: 3362
- Spec cleaning
- remove old obsoletes
- remove ldconfig in post (handled in filetriggers)
- imported package lua

